@@ -31,15 +31,25 @@ import sys
 if sys.version_info >= (2, 6):
     from functools import reduce
 
-class error(IOError): pass
-class FLACNoHeaderError(error): pass
-class FLACVorbisError(ValueError, error): pass
+
+class error(IOError):
+    pass
+
+
+class FLACNoHeaderError(error):
+    pass
+
+
+class FLACVorbisError(ValueError, error):
+    pass
+
 
 def to_int_be(string):
     """Convert an arbitrarily-long string to a long using big-endian
     byte order."""
     return reduce(lambda a, b: (a << 8) + ord(b), string, 0L)
 
+
 class StrictFileObject(object):
     """Wraps a file-like object and raises an exception if the requested
     amount of data to read isn't returned."""
@@ -53,13 +63,14 @@ class StrictFileObject(object):
     def read(self, size=-1):
         data = self._fileobj.read(size)
         if size >= 0 and len(data) != size:
-            raise error("file said %d bytes, read %d bytes" %(
+            raise error("file said %d bytes, read %d bytes" % (
                         size, len(data)))
         return data
 
     def tryread(self, *args):
         return self._fileobj.read(*args)
 
+
 class MetadataBlock(object):
     """A generic block of FLAC metadata.
 
@@ -67,7 +78,8 @@ class MetadataBlock(object):
     blocks, and also as a container for data blobs of unknown blocks.
 
     Attributes:
-    data -- raw binary data for this block
+
+    * data -- raw binary data for this block
     """
 
     _distrust_size = False
@@ -85,9 +97,13 @@ class MetadataBlock(object):
                 data = StrictFileObject(data)
             self.load(data)
 
-    def load(self, data): self.data = data.read()
-    def write(self): return self.data
+    def load(self, data):
+        self.data = data.read()
 
+    def write(self):
+        return self.data
+
+    @staticmethod
     def writeblocks(blocks):
         """Render metadata block as a byte string."""
         data = []
@@ -100,8 +116,8 @@ class MetadataBlock(object):
             length = struct.pack(">I", len(datum))[-3:]
             data.append(byte + length + datum)
         return "".join(data)
-    writeblocks = staticmethod(writeblocks)
 
+    @staticmethod
     def group_padding(blocks):
         """Consolidate FLAC padding metadata blocks.
 
@@ -109,13 +125,13 @@ class MetadataBlock(object):
         this adds several bytes of padding for each merged block."""
         paddings = filter(lambda x: isinstance(x, Padding), blocks)
         map(blocks.remove, paddings)
-        padding = Padding()
         # total padding size is the sum of padding sizes plus 4 bytes
         # per removed header.
         size = sum([padding.length for padding in paddings])
+        padding = Padding()
         padding.length = size + 4 * (len(paddings) - 1)
         blocks.append(padding)
-    group_padding = staticmethod(group_padding)
+
 
 class StreamInfo(MetadataBlock):
     """FLAC stream information.
@@ -127,25 +143,29 @@ class StreamInfo(MetadataBlock):
     attributes of this block.
 
     Attributes:
-    min_blocksize -- minimum audio block size
-    max_blocksize -- maximum audio block size
-    sample_rate -- audio sample rate in Hz
-    channels -- audio channels (1 for mono, 2 for stereo)
-    bits_per_sample -- bits per sample
-    total_samples -- total samples in file
-    length -- audio length in seconds
+
+    * min_blocksize -- minimum audio block size
+    * max_blocksize -- maximum audio block size
+    * sample_rate -- audio sample rate in Hz
+    * channels -- audio channels (1 for mono, 2 for stereo)
+    * bits_per_sample -- bits per sample
+    * total_samples -- total samples in file
+    * length -- audio length in seconds
     """
 
     code = 0
 
     def __eq__(self, other):
-        try: return (self.min_blocksize == other.min_blocksize and
-                     self.max_blocksize == other.max_blocksize and
-                     self.sample_rate == other.sample_rate and
-                     self.channels == other.channels and
-                     self.bits_per_sample == other.bits_per_sample and
-                     self.total_samples == other.total_samples)
-        except: return False
+        try:
+            return (self.min_blocksize == other.min_blocksize and
+                    self.max_blocksize == other.max_blocksize and
+                    self.sample_rate == other.sample_rate and
+                    self.channels == other.channels and
+                    self.bits_per_sample == other.bits_per_sample and
+                    self.total_samples == other.total_samples)
+        except:
+            return False
+
     __hash__ = MetadataBlock.__hash__
 
     def load(self, data):
@@ -188,7 +208,7 @@ class StreamInfo(MetadataBlock):
         byte += ((self.bits_per_sample - 1) >> 4) & 1
         f.write(chr(byte))
         # 4 bits of bps, 4 of sample count
-        byte = ((self.bits_per_sample - 1) & 0xF)  << 4
+        byte = ((self.bits_per_sample - 1) & 0xF) << 4
         byte += (self.total_samples >> 32) & 0xF
         f.write(chr(byte))
         # last 32 of sample count
@@ -203,6 +223,7 @@ class StreamInfo(MetadataBlock):
     def pprint(self):
         return "FLAC, %.2f seconds, %d Hz" % (self.length, self.sample_rate)
 
+
 class SeekPoint(tuple):
     """A single seek point in a FLAC file.
 
@@ -214,23 +235,27 @@ class SeekPoint(tuple):
     may be any number of them.
 
     Attributes:
-    first_sample -- sample number of first sample in the target frame
-    byte_offset -- offset from first frame to target frame
-    num_samples -- number of samples in target frame
+
+    * first_sample -- sample number of first sample in the target frame
+    * byte_offset -- offset from first frame to target frame
+    * num_samples -- number of samples in target frame
     """
 
     def __new__(cls, first_sample, byte_offset, num_samples):
-        return super(cls, SeekPoint).__new__(cls, (first_sample,
-            byte_offset, num_samples))
+        return super(cls, SeekPoint).__new__(
+            cls, (first_sample, byte_offset, num_samples))
+
     first_sample = property(lambda self: self[0])
     byte_offset = property(lambda self: self[1])
     num_samples = property(lambda self: self[2])
 
+
 class SeekTable(MetadataBlock):
     """Read and write FLAC seek tables.
 
     Attributes:
-    seekpoints -- list of SeekPoint objects
+
+    * seekpoints -- list of SeekPoint objects
     """
 
     __SEEKPOINT_FORMAT = '>QQH'
@@ -243,8 +268,11 @@ class SeekTable(MetadataBlock):
         super(SeekTable, self).__init__(data)
 
     def __eq__(self, other):
-        try: return (self.seekpoints == other.seekpoints)
-        except (AttributeError, TypeError): return False
+        try:
+            return (self.seekpoints == other.seekpoints)
+        except (AttributeError, TypeError):
+            return False
+
     __hash__ = MetadataBlock.__hash__
 
     def load(self, data):
@@ -258,7 +286,8 @@ class SeekTable(MetadataBlock):
     def write(self):
         f = StringIO()
         for seekpoint in self.seekpoints:
-            packed = struct.pack(self.__SEEKPOINT_FORMAT,
+            packed = struct.pack(
+                self.__SEEKPOINT_FORMAT,
                 seekpoint.first_sample, seekpoint.byte_offset,
                 seekpoint.num_samples)
             f.write(packed)
@@ -267,6 +296,7 @@ class SeekTable(MetadataBlock):
     def __repr__(self):
         return "<%s seekpoints=%r>" % (type(self).__name__, self.seekpoints)
 
+
 class VCFLACDict(VCommentDict):
     """Read and write FLAC Vorbis comments.
 
@@ -283,6 +313,7 @@ class VCFLACDict(VCommentDict):
     def write(self, framing=False):
         return super(VCFLACDict, self).write(framing=framing)
 
+
 class CueSheetTrackIndex(tuple):
     """Index for a track in a cuesheet.
 
@@ -293,16 +324,19 @@ class CueSheetTrackIndex(tuple):
     divisible by 588 samples.
 
     Attributes:
-    index_number -- index point number
-    index_offset -- offset in samples from track start
+
+    * index_number -- index point number
+    * index_offset -- offset in samples from track start
     """
-    
+
     def __new__(cls, index_number, index_offset):
-        return super(cls, CueSheetTrackIndex).__new__(cls,
-            (index_number, index_offset))
+        return super(cls, CueSheetTrackIndex).__new__(
+            cls, (index_number, index_offset))
+
     index_number = property(lambda self: self[0])
     index_offset = property(lambda self: self[1])
 
+
 class CueSheetTrack(object):
     """A track in a cuesheet.
 
@@ -312,12 +346,13 @@ class CueSheetTrack(object):
     which must have none.
 
     Attributes:
-    track_number -- track number
-    start_offset -- track offset in samples from start of FLAC stream
-    isrc -- ISRC code
-    type -- 0 for audio, 1 for digital data
-    pre_emphasis -- true if the track is recorded with pre-emphasis
-    indexes -- list of CueSheetTrackIndex objects
+
+    * track_number -- track number
+    * start_offset -- track offset in samples from start of FLAC stream
+    * isrc -- ISRC code
+    * type -- 0 for audio, 1 for digital data
+    * pre_emphasis -- true if the track is recorded with pre-emphasis
+    * indexes -- list of CueSheetTrackIndex objects
     """
 
     def __init__(self, track_number, start_offset, isrc='', type_=0,
@@ -330,20 +365,24 @@ class CueSheetTrack(object):
         self.indexes = []
 
     def __eq__(self, other):
-        try: return (self.track_number == other.track_number and
-                     self.start_offset == other.start_offset and
-                     self.isrc == other.isrc and
-                     self.type == other.type and
-                     self.pre_emphasis == other.pre_emphasis and
-                     self.indexes == other.indexes)
-        except (AttributeError, TypeError): return False
+        try:
+            return (self.track_number == other.track_number and
+                    self.start_offset == other.start_offset and
+                    self.isrc == other.isrc and
+                    self.type == other.type and
+                    self.pre_emphasis == other.pre_emphasis and
+                    self.indexes == other.indexes)
+        except (AttributeError, TypeError):
+            return False
+
     __hash__ = object.__hash__
 
     def __repr__(self):
         return ("<%s number=%r, offset=%d, isrc=%r, type=%r, "
                 "pre_emphasis=%r, indexes=%r)>") % (
-            type(self).__name__, self.track_number, self.start_offset,
-            self.isrc, self.type, self.pre_emphasis, self.indexes)
+                    type(self).__name__, self.track_number, self.start_offset,
+                    self.isrc, self.type, self.pre_emphasis, self.indexes)
+
 
 class CueSheet(MetadataBlock):
     """Read and write FLAC embedded cue sheets.
@@ -353,11 +392,12 @@ class CueSheet(MetadataBlock):
     in the cue sheet.
 
     Attributes:
-    media_catalog_number -- media catalog number in ASCII
-    lead_in_samples -- number of lead-in samples
-    compact_disc -- true if the cuesheet corresponds to a compact disc
-    tracks -- list of CueSheetTrack objects
-    lead_out -- lead-out as CueSheetTrack or None if lead-out was not found
+
+    * media_catalog_number -- media catalog number in ASCII
+    * lead_in_samples -- number of lead-in samples
+    * compact_disc -- true if the cuesheet corresponds to a compact disc
+    * tracks -- list of CueSheetTrack objects
+    * lead_out -- lead-out as CueSheetTrack or None if lead-out was not found
     """
 
     __CUESHEET_FORMAT = '>128sQB258xB'
@@ -380,10 +420,12 @@ class CueSheet(MetadataBlock):
     def __eq__(self, other):
         try:
             return (self.media_catalog_number == other.media_catalog_number and
-                     self.lead_in_samples == other.lead_in_samples and
-                     self.compact_disc == other.compact_disc and
-                     self.tracks == other.tracks)
-        except (AttributeError, TypeError): return False
+                    self.lead_in_samples == other.lead_in_samples and
+                    self.compact_disc == other.compact_disc and
+                    self.tracks == other.tracks)
+        except (AttributeError, TypeError):
+            return False
+
     __hash__ = MetadataBlock.__hash__
 
     def load(self, data):
@@ -394,7 +436,7 @@ class CueSheet(MetadataBlock):
         self.lead_in_samples = lead_in_samples
         self.compact_disc = bool(flags & 0x80)
         self.tracks = []
-        for i in range(num_tracks): 
+        for i in range(num_tracks):
             track = data.read(self.__CUESHEET_TRACK_SIZE)
             start_offset, track_number, isrc_padded, flags, num_indexes = \
                 struct.unpack(self.__CUESHEET_TRACK_FORMAT, track)
@@ -410,11 +452,12 @@ class CueSheet(MetadataBlock):
                 val.indexes.append(
                     CueSheetTrackIndex(index_number, index_offset))
             self.tracks.append(val)
-            
+
     def write(self):
         f = StringIO()
         flags = 0
-        if self.compact_disc: flags |= 0x80
+        if self.compact_disc:
+            flags |= 0x80
         packed = struct.pack(
             self.__CUESHEET_FORMAT, self.media_catalog_number,
             self.lead_in_samples, flags, len(self.tracks))
@@ -422,7 +465,8 @@ class CueSheet(MetadataBlock):
         for track in self.tracks:
             track_flags = 0
             track_flags |= (track.type & 1) << 7
-            if track.pre_emphasis: track_flags |= 0x40
+            if track.pre_emphasis:
+                track_flags |= 0x40
             track_packed = struct.pack(
                 self.__CUESHEET_TRACK_FORMAT, track.start_offset,
                 track.track_number, track.isrc, track_flags,
@@ -438,22 +482,24 @@ class CueSheet(MetadataBlock):
     def __repr__(self):
         return ("<%s media_catalog_number=%r, lead_in=%r, compact_disc=%r, "
                 "tracks=%r>") % (
-            type(self).__name__, self.media_catalog_number,
-            self.lead_in_samples, self.compact_disc, self.tracks)
+                    type(self).__name__, self.media_catalog_number,
+                    self.lead_in_samples, self.compact_disc, self.tracks)
+
 
 class Picture(MetadataBlock):
     """Read and write FLAC embed pictures.
 
     Attributes:
-    type -- picture type (same as types for ID3 APIC frames)
-    mime -- MIME type of the picture
-    desc -- picture's description
-    width -- width in pixels
-    height -- height in pixels
-    depth -- color depth in bits-per-pixel
-    colors -- number of colors for indexed palettes (like GIF),
-              0 for non-indexed
-    data -- picture data
+
+    * type -- picture type (same as types for ID3 APIC frames)
+    * mime -- MIME type of the picture
+    * desc -- picture's description
+    * width -- width in pixels
+    * height -- height in pixels
+    * depth -- color depth in bits-per-pixel
+    * colors -- number of colors for indexed palettes (like GIF),
+      0 for non-indexed
+    * data -- picture data
     """
 
     code = 6
@@ -471,15 +517,18 @@ class Picture(MetadataBlock):
         super(Picture, self).__init__(data)
 
     def __eq__(self, other):
-        try: return (self.type == other.type and
-                     self.mime == other.mime and
-                     self.desc == other.desc and
-                     self.width == other.width and
-                     self.height == other.height and
-                     self.depth == other.depth and
-                     self.colors == other.colors and
-                     self.data == other.data)
-        except (AttributeError, TypeError): return False
+        try:
+            return (self.type == other.type and
+                    self.mime == other.mime and
+                    self.desc == other.desc and
+                    self.width == other.width and
+                    self.height == other.height and
+                    self.depth == other.depth and
+                    self.colors == other.colors and
+                    self.data == other.data)
+        except (AttributeError, TypeError):
+            return False
+
     __hash__ = MetadataBlock.__hash__
 
     def load(self, data):
@@ -508,6 +557,7 @@ class Picture(MetadataBlock):
         return "<%s '%s' (%d bytes)>" % (type(self).__name__, self.mime,
                                          len(self.data))
 
+
 class Padding(MetadataBlock):
     """Empty padding space for metadata blocks.
 
@@ -519,10 +569,15 @@ class Padding(MetadataBlock):
 
     code = 1
 
-    def __init__(self, data=""): super(Padding, self).__init__(data)
-    def load(self, data): self.length = len(data.read())
+    def __init__(self, data=""):
+        super(Padding, self).__init__(data)
+
+    def load(self, data):
+        self.length = len(data.read())
+
     def write(self):
-        try: return "\x00" * self.length
+        try:
+            return "\x00" * self.length
         # On some 64 bit platforms this won't generate a MemoryError
         # or OverflowError since you might have enough RAM, but it
         # still generates a ValueError. On other 64 bit platforms,
@@ -531,33 +586,38 @@ class Padding(MetadataBlock):
         # do, writeblocks will catch it.
         except (OverflowError, ValueError, MemoryError):
             raise error("cannot write %d bytes" % self.length)
+
     def __eq__(self, other):
         return isinstance(other, Padding) and self.length == other.length
+
     __hash__ = MetadataBlock.__hash__
+
     def __repr__(self):
         return "<%s (%d bytes)>" % (type(self).__name__, self.length)
 
+
 class FLAC(FileType):
     """A FLAC audio file.
-    
+
     Attributes:
-    info -- stream information (length, bitrate, sample rate)
-    tags -- metadata tags, if any
-    cuesheet -- CueSheet object, if any
-    seektable -- SeekTable object, if any
-    pictures -- list of embedded pictures
+
+    * info -- stream information (length, bitrate, sample rate)
+    * tags -- metadata tags, if any
+    * cuesheet -- CueSheet object, if any
+    * seektable -- SeekTable object, if any
+    * pictures -- list of embedded pictures
     """
 
     _mimes = ["audio/x-flac", "application/x-flac"]
 
     METADATA_BLOCKS = [StreamInfo, Padding, None, SeekTable, VCFLACDict,
-        CueSheet, Picture]
+                       CueSheet, Picture]
     """Known metadata block types, indexed by ID."""
 
+    @staticmethod
     def score(filename, fileobj, header):
         return (header.startswith("fLaC") +
                 filename.lower().endswith(".flac") * 3)
-    score = staticmethod(score)
 
     def __read_metadata_block(self, fileobj):
         byte = ord(fileobj.read(1))
@@ -609,7 +669,9 @@ class FLAC(FileType):
         if self.tags is None:
             self.tags = VCFLACDict()
             self.metadata_blocks.append(self.tags)
-        else: raise FLACVorbisError("a Vorbis comment already exists")
+        else:
+            raise FLACVorbisError("a Vorbis comment already exists")
+
     add_vorbiscomment = add_tags
 
     def delete(self, filename=None):
@@ -617,7 +679,8 @@ class FLAC(FileType):
 
         If no filename is given, the one most recently loaded is used.
         """
-        if filename is None: filename = self.filename
+        if filename is None:
+            filename = self.filename
         for s in list(self.metadata_blocks):
             if isinstance(s, VCFLACDict):
                 self.metadata_blocks.remove(s)
@@ -648,7 +711,9 @@ class FLAC(FileType):
         except (AttributeError, IndexError):
             raise FLACNoHeaderError("Stream info block not found")
 
-    info = property(lambda s: s.metadata_blocks[0])
+    @property
+    def info(self):
+        return self.metadata_blocks[0]
 
     def add_picture(self, picture):
         """Add a new picture to the file."""
@@ -659,9 +724,10 @@ class FLAC(FileType):
         self.metadata_blocks = filter(lambda b: b.code != Picture.code,
                                       self.metadata_blocks)
 
-    def __get_pictures(self):
+    @property
+    def pictures(self):
+        """List of embedded pictures"""
         return filter(lambda b: b.code == Picture.code, self.metadata_blocks)
-    pictures = property(__get_pictures, doc="List of embedded pictures")
 
     def save(self, filename=None, deleteid3=False):
         """Save metadata blocks to a file.
@@ -669,7 +735,8 @@ class FLAC(FileType):
         If no filename is given, the one most recently loaded is used.
         """
 
-        if filename is None: filename = self.filename
+        if filename is None:
+            filename = self.filename
         f = open(filename, 'rb+')
 
         try:
@@ -679,7 +746,8 @@ class FLAC(FileType):
             MetadataBlock.group_padding(self.metadata_blocks)
 
             header = self.__check_header(f)
-            available = self.__find_audio_offset(f) - header # "fLaC" and maybe ID3
+            # "fLaC" and maybe ID3
+            available = self.__find_audio_offset(f) - header
             data = MetadataBlock.writeblocks(self.metadata_blocks)
 
             # Delete ID3v2
@@ -712,8 +780,10 @@ class FLAC(FileType):
 
             # Delete ID3v1
             if deleteid3:
-                try: f.seek(-128, 2)
-                except IOError: pass
+                try:
+                    f.seek(-128, 2)
+                except IOError:
+                    pass
                 else:
                     if f.read(3) == "TAG":
                         f.seek(-128, 2)
@@ -747,14 +817,17 @@ class FLAC(FileType):
             if header[:3] == "ID3":
                 size = 14 + BitPaddedInt(fileobj.read(6)[2:])
                 fileobj.seek(size - 4)
-                if fileobj.read(4) != "fLaC": size = None
+                if fileobj.read(4) != "fLaC":
+                    size = None
         if size is None:
             raise FLACNoHeaderError(
                 "%r is not a valid FLAC file" % fileobj.name)
         return size
 
+
 Open = FLAC
 
+
 def delete(filename):
     """Remove tags from a file."""
     FLAC(filename).delete()
