@@ -1,10 +1,9 @@
 import os
-import sys
 import shutil
 import pickle
 from tests import add, TestCase
 from mutagen.id3 import ID3FileType
-from mutagen.easyid3 import EasyID3, error as ID3Error, delete
+from mutagen.easyid3 import EasyID3, error as ID3Error
 from tempfile import mkstemp
 
 class TEasyID3(TestCase):
@@ -154,6 +153,10 @@ class TEasyID3(TestCase):
         self.id3["performer:foo"] = "Joe"
         self.failUnlessRaises(KeyError, self.id3.__delitem__, "performer:bar")
 
+    def test_txxx_empty(self):
+        # http://code.google.com/p/mutagen/issues/detail?id=135
+        self.id3["asin"] = ""
+
     def test_txxx_set_get(self):
         self.failIf("asin" in self.id3.keys())
         self.id3["asin"] = "Hello"
@@ -256,6 +259,49 @@ class TEasyID3(TestCase):
         # http://code.google.com/p/mutagen/issues/detail?id=102
         pickle.dumps(self.id3)
 
+    def test_get_fallback(self):
+        called = []
+
+        def get_func(id3, key):
+            id3.getall("")
+            self.failUnlessEqual(key, "nope")
+            called.append(1)
+        self.id3.GetFallback = get_func
+        self.id3["nope"]
+        self.failUnless(called)
+
+    def test_set_fallback(self):
+        called = []
+
+        def set_func(id3, key, value):
+            id3.getall("")
+            self.failUnlessEqual(key, "nope")
+            self.failUnlessEqual(value, ["foo"])
+            called.append(1)
+        self.id3.SetFallback = set_func
+        self.id3["nope"] = "foo"
+        self.failUnless(called)
+
+    def test_del_fallback(self):
+        called = []
+
+        def del_func(id3, key):
+            id3.getall("")
+            self.failUnlessEqual(key, "nope")
+            called.append(1)
+        self.id3.DeleteFallback = del_func
+        del self.id3["nope"]
+        self.failUnless(called)
+
+    def test_list_fallback(self):
+        def list_func(id3, key):
+            id3.getall("")
+            self.failIf(key)
+            return ["somekey"]
+
+        self.id3.ListFallback = list_func
+        self.failUnlessEqual(self.id3.keys(), ["somekey"])
+
     def tearDown(self):
         os.unlink(self.filename)
 
