@@ -1,8 +1,9 @@
 import os; from os.path import join
 import shutil
-from unittest import TestCase
+from tests import TestCase
 from tests import add
-from mutagen.id3 import ID3, BitPaddedInt, COMR, Frames, Frames_2_2, ID3Warning, ID3JunkFrameError
+from mutagen import id3
+from mutagen.id3 import ID3, COMR, Frames, Frames_2_2, ID3Warning, ID3JunkFrameError
 from StringIO import StringIO
 import warnings
 warnings.simplefilter('error', ID3Warning)
@@ -12,7 +13,6 @@ _23 = ID3(); _23.version = (2,3,0)
 _24 = ID3(); _24.version = (2,4,0)
 
 class ID3GetSetDel(TestCase):
-    uses_mmap = False
 
     def setUp(self):
         self.i = ID3()
@@ -63,11 +63,10 @@ class ID3GetSetDel(TestCase):
         self.assert_(self.i.getall("FOOB") in [[t, t2], [t2, t]])
 
 class ID3Loading(TestCase):
-    uses_mmap = False
-
 
     empty = join('tests', 'data', 'emptyfile.mp3')
     silence = join('tests', 'data', 'silence-44-s.mp3')
+    unsynch = join('tests', 'data', 'id3v23_unsynch.id3')
 
     def test_empty_file(self):
         name = self.empty
@@ -99,6 +98,11 @@ class ID3Loading(TestCase):
         id3._ID3__fileobj = StringIO('ID3\x04\x00\x1f\x00\x00\x00\x00')
         self.assertRaises(ValueError, id3._ID3__load_header)
 
+    def test_header_2_4_unsynch_size(self):
+        id3 = ID3()
+        id3._ID3__fileobj = StringIO('ID3\x04\x00\x10\x00\x00\x00\xFF')
+        self.assertRaises(ValueError, id3._ID3__load_header)
+
     def test_header_2_4_allow_footer(self):
         id3 = ID3()
         id3._ID3__fileobj = StringIO('ID3\x04\x00\x10\x00\x00\x00\x00')
@@ -135,6 +139,12 @@ class ID3Loading(TestCase):
         self.assertEquals(id3._ID3__extsize, 1)
         self.assertEquals(id3._ID3__extdata, '\x5a')
 
+    def test_header_2_4_extended_unsynch_size(self):
+        id3 = ID3()
+        id3._ID3__fileobj = StringIO(
+            'ID3\x04\x00\x40\x00\x00\x00\x00\x00\x00\x00\xFF\x5a')
+        self.assertRaises(ValueError, id3._ID3__load_header)
+
     def test_header_2_4_extended_but_not(self):
         id3 = ID3()
         id3._ID3__fileobj = StringIO(
@@ -171,6 +181,10 @@ class ID3Loading(TestCase):
         tag = id3._ID3__load_framedata(Frames["TPE2"], 0, badsync)
         self.assertEquals(tag, [u"\xff", u"ab"])
 
+    def test_load_v23_unsynch(self):
+        id3 = ID3(self.unsynch)
+        self.assertEquals(id3["TPE1"], ["Nina Simone"])
+
     def test_insane__ID3__fullread(self):
         id3 = ID3()
         id3._ID3__filesize = 0
@@ -178,7 +192,6 @@ class ID3Loading(TestCase):
         self.assertRaises(EOFError, id3._ID3__fullread, 3)
 
 class Issue21(TestCase):
-    uses_mmap = False
 
     # Files with bad extended header flags failed to read tags.
     # Ensure the extended header is turned off, and the frames are
@@ -198,7 +211,6 @@ class Issue21(TestCase):
 add(Issue21)
 
 class ID3Tags(TestCase):
-    uses_mmap = False
 
     def setUp(self):
         self.silence = join('tests', 'data', 'silence-44-s.mp3')
@@ -285,7 +297,6 @@ class ID3Tags(TestCase):
                 RBUF()._readData, '\x00\x01\x00\x01\x00\x00\x00\x00#xyz')
 
 class ID3v1Tags(TestCase):
-    uses_mmap = False
 
     def setUp(self):
         self.silence = join('tests', 'data', 'silence-44-s-v1.mp3')
@@ -423,7 +434,6 @@ class TestWriteID3v1(TestCase):
 add(TestWriteID3v1)
 
 class TestV22Tags(TestCase):
-    uses_mmap = False
 
     def setUp(self):
         filename = os.path.join("tests", "data", "id3v22-test.mp3")
@@ -635,6 +645,11 @@ def TestReadTags():
      dict(frameid='COMM', url='http://www.example.org/COMM.txt',
           data='engfoo')],
 
+    # iTunes podcast frames
+    ['TGID', '\x00i', u'i', '', dict(encoding=0)],
+    ['TDES', '\x00ii', u'ii', '', dict(encoding=0)],
+    ['WFED', 'http://zzz', 'http://zzz', '', {}],
+
     # 2.2 tags
     ['UFI', 'own\x00data', 'data', '', dict(data='data', owner='own')],
     ['SLT', ('\x00eng\x02\x01some lyrics\x00foo\x00\x00\x00\x00\x01bar'
@@ -775,6 +790,12 @@ def TestReadTags():
             for spec in TAG._framespec:
                 attr = spec.name
                 self.assertEquals(getattr(tag, attr), getattr(tag2, attr))
+
+            # test __str__, __unicode__
+            self.assertTrue(isinstance(tag.__str__(), str))
+            if hasattr(tag, "__unicode__"):
+                self.assertTrue(isinstance(tag.__unicode__(), unicode))
+
         repr_tests['test_repr_%s_%d' % (tag, i)] = test_tag_repr
 
         def test_tag_write(self, tag=tag, data=data):
@@ -789,16 +810,12 @@ def TestReadTags():
         write_tests['test_write_%s_%d' % (tag, i)] = test_tag_write
 
     testcase = type('TestReadTags', (TestCase,), load_tests)
-    testcase.uses_mmap = False
     add(testcase)
     testcase = type('TestReadReprTags', (TestCase,), repr_tests)
-    testcase.uses_mmap = False
     add(testcase)
     testcase = type('TestReadWriteTags', (TestCase,), write_tests)
-    testcase.uses_mmap = False
     add(testcase)
 
-    test_tests = {}
     from mutagen.id3 import Frames, Frames_2_2
     check = dict.fromkeys(Frames.keys() + Frames_2_2.keys())
     tested_tags = dict.fromkeys([row[0] for row in tests])
@@ -806,317 +823,15 @@ def TestReadTags():
         def check(self, tag=tag): self.assert_(tag in tested_tags)
         tested_tags['test_' + tag + '_tested'] = check
     testcase = type('TestTestedTags', (TestCase,), tested_tags)
-    testcase.uses_mmap = False
     add(testcase)
 
 TestReadTags()
 del TestReadTags
 
-class BitPaddedIntTest(TestCase):
-    uses_mmap = False
-
-    def test_zero(self):
-        self.assertEquals(BitPaddedInt('\x00\x00\x00\x00'), 0)
-
-    def test_1(self):
-        self.assertEquals(BitPaddedInt('\x00\x00\x00\x01'), 1)
-
-    def test_1l(self):
-        self.assertEquals(BitPaddedInt('\x01\x00\x00\x00', bigendian=False), 1)
-
-    def test_129(self):
-        self.assertEquals(BitPaddedInt('\x00\x00\x01\x01'), 0x81)
-
-    def test_129b(self):
-        self.assertEquals(BitPaddedInt('\x00\x00\x01\x81'), 0x81)
-
-    def test_65(self):
-        self.assertEquals(BitPaddedInt('\x00\x00\x01\x81', 6), 0x41)
-
-    def test_32b(self):
-        self.assertEquals(BitPaddedInt('\xFF\xFF\xFF\xFF', bits=8),
-            0xFFFFFFFF)
-
-    def test_32bi(self):
-        self.assertEquals(BitPaddedInt(0xFFFFFFFF, bits=8), 0xFFFFFFFF)
-
-    def test_s32b(self):
-        self.assertEquals(BitPaddedInt('\xFF\xFF\xFF\xFF', bits=8).as_str(),
-            '\xFF\xFF\xFF\xFF')
-
-    def test_s0(self):
-        self.assertEquals(BitPaddedInt.to_str(0), '\x00\x00\x00\x00')
-
-    def test_s1(self):
-        self.assertEquals(BitPaddedInt.to_str(1), '\x00\x00\x00\x01')
-
-    def test_s1l(self):
-        self.assertEquals(
-            BitPaddedInt.to_str(1, bigendian=False), '\x01\x00\x00\x00')
-
-    def test_s129(self):
-        self.assertEquals(BitPaddedInt.to_str(129), '\x00\x00\x01\x01')
-
-    def test_s65(self):
-        self.assertEquals(BitPaddedInt.to_str(0x41, 6), '\x00\x00\x01\x01')
-
-    def test_w129(self):
-        self.assertEquals(BitPaddedInt.to_str(129, width=2), '\x01\x01')
-
-    def test_w129l(self):
-        self.assertEquals(
-            BitPaddedInt.to_str(129, width=2, bigendian=False), '\x01\x01')
-
-    def test_wsmall(self):
-        self.assertRaises(ValueError, BitPaddedInt.to_str, 129, width=1)
-
-    def test_str_int_init(self):
-        from struct import pack
-        self.assertEquals(BitPaddedInt(238).as_str(),
-                BitPaddedInt(pack('>L', 238)).as_str())
-
-    def test_varwidth(self):
-        self.assertEquals(len(BitPaddedInt.to_str(100)), 4)
-        self.assertEquals(len(BitPaddedInt.to_str(100, width=-1)), 4)
-        self.assertEquals(len(BitPaddedInt.to_str(2**32, width=-1)), 5)
 
 
-class SpecSanityChecks(TestCase):
-    uses_mmap = False
-
-    def test_bytespec(self):
-        from mutagen.id3 import ByteSpec
-        s = ByteSpec('name')
-        self.assertEquals((97, 'bcdefg'), s.read(None, 'abcdefg'))
-        self.assertEquals('a', s.write(None, 97))
-        self.assertRaises(TypeError, s.write, None, 'abc')
-        self.assertRaises(TypeError, s.write, None, None)
-
-    def test_encodingspec(self):
-        from mutagen.id3 import EncodingSpec
-        s = EncodingSpec('name')
-        self.assertEquals((0, 'abcdefg'), s.read(None, 'abcdefg'))
-        self.assertEquals((3, 'abcdefg'), s.read(None, '\x03abcdefg'))
-        self.assertEquals('\x00', s.write(None, 0))
-        self.assertRaises(TypeError, s.write, None, 'abc')
-        self.assertRaises(TypeError, s.write, None, None)
-
-    def test_stringspec(self):
-        from mutagen.id3 import StringSpec
-        s = StringSpec('name', 3)
-        self.assertEquals(('abc', 'defg'),  s.read(None, 'abcdefg'))
-        self.assertEquals('abc', s.write(None, 'abcdefg'))
-        self.assertEquals('\x00\x00\x00', s.write(None, None))
-        self.assertEquals('\x00\x00\x00', s.write(None, '\x00'))
-        self.assertEquals('a\x00\x00', s.write(None, 'a'))
-
-    def test_binarydataspec(self):
-        from mutagen.id3 import BinaryDataSpec
-        s = BinaryDataSpec('name')
-        self.assertEquals(('abcdefg', ''), s.read(None, 'abcdefg'))
-        self.assertEquals('None',  s.write(None, None))
-        self.assertEquals('43',  s.write(None, 43))
-
-    def test_encodedtextspec(self):
-        from mutagen.id3 import EncodedTextSpec, Frame
-        s = EncodedTextSpec('name')
-        f = Frame(); f.encoding = 0
-        self.assertEquals(('abcd', 'fg'), s.read(f, 'abcd\x00fg'))
-        self.assertEquals('abcdefg\x00', s.write(f, 'abcdefg'))
-        self.assertRaises(AttributeError, s.write, f, None)
-
-    def test_timestampspec(self):
-        from mutagen.id3 import TimeStampSpec, Frame, ID3TimeStamp
-        s = TimeStampSpec('name')
-        f = Frame(); f.encoding = 0
-        self.assertEquals((ID3TimeStamp('ab'), 'fg'), s.read(f, 'ab\x00fg'))
-        self.assertEquals((ID3TimeStamp('1234'), ''), s.read(f, '1234\x00'))
-        self.assertEquals('1234\x00', s.write(f, ID3TimeStamp('1234')))
-        self.assertRaises(AttributeError, s.write, f, None)
-
-    def test_volumeadjustmentspec(self):
-        from mutagen.id3 import VolumeAdjustmentSpec
-        s = VolumeAdjustmentSpec('gain')
-        self.assertEquals((0.0, ''), s.read(None, '\x00\x00'))
-        self.assertEquals((2.0, ''), s.read(None, '\x04\x00'))
-        self.assertEquals((-2.0, ''), s.read(None, '\xfc\x00'))
-        self.assertEquals('\x00\x00', s.write(None, 0.0))
-        self.assertEquals('\x04\x00', s.write(None, 2.0))
-        self.assertEquals('\xfc\x00', s.write(None, -2.0))
-
-class FrameSanityChecks(TestCase):
-    uses_mmap = False
-
-    def test_TF(self):
-        from mutagen.id3 import TextFrame
-        self.assert_(isinstance(TextFrame(text='text'), TextFrame))
-
-    def test_UF(self):
-        from mutagen.id3 import UrlFrame
-        self.assert_(isinstance(UrlFrame('url'), UrlFrame))
-
-    def test_WXXX(self):
-        from mutagen.id3 import WXXX
-        self.assert_(isinstance(WXXX(url='durl'), WXXX))
-
-    def test_NTF(self):
-        from mutagen.id3 import NumericTextFrame
-        self.assert_(isinstance(NumericTextFrame(text='1'), NumericTextFrame))
-
-    def test_NTPF(self):
-        from mutagen.id3 import NumericPartTextFrame
-        self.assert_(
-            isinstance(NumericPartTextFrame(text='1/2'), NumericPartTextFrame))
-
-    def test_MTF(self):
-        from mutagen.id3 import TextFrame
-        self.assert_(isinstance(TextFrame(text=['a','b']), TextFrame))
-
-    def test_TXXX(self):
-        from mutagen.id3 import TXXX
-        self.assert_(isinstance(TXXX(desc='d',text='text'), TXXX))
-
-    def test_22_uses_direct_ints(self):
-        data = 'TT1\x00\x00\x83\x00' + ('123456789abcdef' * 16)
-        id3 = ID3()
-        id3.version = (2,2,0)
-        tag = list(id3._ID3__read_frames(data, Frames_2_2))[0]
-        self.assertEquals(data[7:7+0x82].decode('latin1'), tag.text[0])
-
-    def test_frame_too_small(self):
-        self.assertEquals([], list(_24._ID3__read_frames('012345678', Frames)))
-        self.assertEquals([], list(_23._ID3__read_frames('012345678', Frames)))
-        self.assertEquals([], list(_22._ID3__read_frames('01234', Frames_2_2)))
-        self.assertEquals(
-            [], list(_22._ID3__read_frames('TT1'+'\x00'*3, Frames_2_2)))
-
-    def test_unknown_22_frame(self):
-        data = 'XYZ\x00\x00\x01\x00'
-        self.assertEquals([data], list(_22._ID3__read_frames(data, {})))
-
-
-    def test_zlib_latin1(self):
-        from mutagen.id3 import TPE1
-        tag = TPE1.fromData(_24, 0x9, '\x00\x00\x00\x0f'
-                'x\x9cc(\xc9\xc8,V\x00\xa2D\xfd\x92\xd4\xe2\x12\x00&\x7f\x05%')
-        self.assertEquals(tag.encoding, 0)
-        self.assertEquals(tag, ['this is a/test'])
-
-    def test_datalen_but_not_compressed(self):
-        from mutagen.id3 import TPE1
-        tag = TPE1.fromData(_24, 0x01, '\x00\x00\x00\x06\x00A test')
-        self.assertEquals(tag.encoding, 0)
-        self.assertEquals(tag, ['A test'])
-
-    def test_utf8(self):
-        from mutagen.id3 import TPE1
-        tag = TPE1.fromData(_23, 0x00, '\x03this is a test')
-        self.assertEquals(tag.encoding, 3)
-        self.assertEquals(tag, 'this is a test')
-
-    def test_zlib_utf16(self):
-        from mutagen.id3 import TPE1
-        data = ('\x00\x00\x00\x1fx\x9cc\xfc\xff\xaf\x84!\x83!\x93\xa1\x98A'
-                '\x01J&2\xe83\x940\xa4\x02\xd9%\x0c\x00\x87\xc6\x07#')
-        tag = TPE1.fromData(_23, 0x80, data)
-        self.assertEquals(tag.encoding, 1)
-        self.assertEquals(tag, ['this is a/test'])
-
-        tag = TPE1.fromData(_24, 0x08, data)
-        self.assertEquals(tag.encoding, 1)
-        self.assertEquals(tag, ['this is a/test'])
-
-    def test_unsync_encode(self):
-        from mutagen.id3 import unsynch as un
-        for d in ('\xff\xff\xff\xff', '\xff\xf0\x0f\x00', '\xff\x00\x0f\xf0'):
-            self.assertEquals(d, un.decode(un.encode(d)))
-            self.assertNotEqual(d, un.encode(d))
-        self.assertEquals('\xff\x44', un.encode('\xff\x44'))
-        self.assertEquals('\xff\x00\x00', un.encode('\xff\x00'))
-
-    def test_unsync_decode(self):
-        from mutagen.id3 import unsynch as un
-        self.assertRaises(ValueError, un.decode, '\xff\xff\xff\xff')
-        self.assertRaises(ValueError, un.decode, '\xff\xf0\x0f\x00')
-        self.assertRaises(ValueError, un.decode, '\xff\xe0')
-        self.assertEquals('\xff\x44', un.decode('\xff\x44'))
-
-    def test_load_write(self):
-        from mutagen.id3 import TPE1, Frames
-        artists= [s.decode('utf8') for s in
-                  ['\xc2\xb5', '\xe6\x97\xa5\xe6\x9c\xac']]
-        artist = TPE1(encoding=3, text=artists)
-        id3 = ID3()
-        tag = list(id3._ID3__read_frames(
-            id3._ID3__save_frame(artist), Frames))[0]
-        self.assertEquals('TPE1', type(tag).__name__)
-        self.assertEquals(artist.text, tag.text)
-
-    def test_22_to_24(self):
-        from mutagen.id3 import TT1, TIT1
-        id3 = ID3()
-        tt1 = TT1(encoding=0, text=u'whatcha staring at?')
-        id3.loaded_frame(tt1)
-        tit1 = id3['TIT1']
-
-        self.assertEquals(tt1.encoding, tit1.encoding)
-        self.assertEquals(tt1.text, tit1.text)
-        self.assert_('TT1' not in id3)
-
-    def test_single_TXYZ(self):
-        from mutagen.id3 import TIT2
-        self.assertEquals(TIT2(text="a").HashKey, TIT2(text="b").HashKey)
-
-    def test_multi_TXXX(self):
-        from mutagen.id3 import TXXX
-        self.assertEquals(TXXX(text="a").HashKey, TXXX(text="b").HashKey)
-        self.assertNotEquals(TXXX(desc="a").HashKey, TXXX(desc="b").HashKey)
-
-    def test_multi_WXXX(self):
-        from mutagen.id3 import WXXX
-        self.assertEquals(WXXX(text="a").HashKey, WXXX(text="b").HashKey)
-        self.assertNotEquals(WXXX(desc="a").HashKey, WXXX(desc="b").HashKey)
-
-    def test_multi_COMM(self):
-        from mutagen.id3 import COMM
-        self.assertEquals(COMM(text="a").HashKey, COMM(text="b").HashKey)
-        self.assertNotEquals(COMM(desc="a").HashKey, COMM(desc="b").HashKey)
-        self.assertNotEquals(
-            COMM(lang="abc").HashKey, COMM(lang="def").HashKey)
-
-    def test_multi_RVA2(self):
-        from mutagen.id3 import RVA2
-        self.assertEquals(RVA2(gain="1").HashKey, RVA2(gain="2").HashKey)
-        self.assertNotEquals(RVA2(desc="a").HashKey, RVA2(desc="b").HashKey)
-
-    def test_multi_APIC(self):
-        from mutagen.id3 import APIC
-        self.assertEquals(APIC(data="1").HashKey, APIC(data="2").HashKey)
-        self.assertNotEquals(APIC(desc="a").HashKey, APIC(desc="b").HashKey)
-
-    def test_multi_POPM(self):
-        from mutagen.id3 import POPM
-        self.assertEquals(POPM(count=1).HashKey, POPM(count=2).HashKey)
-        self.assertNotEquals(POPM(email="a").HashKey, POPM(email="b").HashKey)
-
-    def test_multi_GEOB(self):
-        from mutagen.id3 import GEOB
-        self.assertEquals(GEOB(data="1").HashKey, GEOB(data="2").HashKey)
-        self.assertNotEquals(GEOB(desc="a").HashKey, GEOB(desc="b").HashKey)
-
-    def test_multi_UFID(self):
-        from mutagen.id3 import UFID
-        self.assertEquals(UFID(data="1").HashKey, UFID(data="2").HashKey)
-        self.assertNotEquals(UFID(owner="a").HashKey, UFID(owner="b").HashKey)
-
-    def test_multi_USER(self):
-        from mutagen.id3 import USER
-        self.assertEquals(USER(text="a").HashKey, USER(text="b").HashKey)
-        self.assertNotEquals(
-            USER(lang="abc").HashKey, USER(lang="def").HashKey)
 
 class UpdateTo24(TestCase):
-    uses_mmap = False
 
     def test_pic(self):
         from mutagen.id3 import PIC
@@ -1169,6 +884,13 @@ class UpdateTo24(TestCase):
         id3.update_to_v24()
         self.failUnlessEqual(id3["TIPL"], [["a", "b"], ["c", "d"]])
 
+    def test_dropped(self):
+        from mutagen.id3 import TIME
+        id3 = ID3()
+        id3.version = (2, 3)
+        id3.add(TIME(encoding=0, text=["1155"]))
+        id3.update_to_v24()
+        self.assertFalse(id3.getall("TIME"))
 
 add(UpdateTo24)
 
@@ -1209,7 +931,6 @@ class Issue97_UpgradeUnknown23(TestCase):
 
     def test_double_update(self):
         from mutagen.id3 import TPE1
-        orig = ID3(self.filename)
         unknown = ID3(self.filename, known_frames={"TPE1": TPE1})
         # Make sure the data doesn't get updated again
         unknown.update_to_v24()
@@ -1230,76 +951,7 @@ class Issue97_UpgradeUnknown23(TestCase):
 add(Issue97_UpgradeUnknown23)
 
 
-class Genres(TestCase):
-    uses_mmap = False
-
-    from mutagen.id3 import TCON
-    from mutagen._constants import GENRES
-
-    def _g(self, s): return self.TCON(text=s).genres
-
-    def test_empty(self): self.assertEquals(self._g(""), [])
-
-    def test_num(self):
-        for i in range(len(self.GENRES)):
-            self.assertEquals(self._g("%02d" % i), [self.GENRES[i]])
-
-    def test_parened_num(self):
-        for i in range(len(self.GENRES)):
-            self.assertEquals(self._g("(%02d)" % i), [self.GENRES[i]])
-
-    def test_unknown(self):
-        self.assertEquals(self._g("(255)"), ["Unknown"])
-        self.assertEquals(self._g("199"), ["Unknown"])
-
-    def test_parened_multi(self):
-        self.assertEquals(self._g("(00)(02)"), ["Blues", "Country"])
-
-    def test_coverremix(self):
-        self.assertEquals(self._g("CR"), ["Cover"])
-        self.assertEquals(self._g("(CR)"), ["Cover"])
-        self.assertEquals(self._g("RX"), ["Remix"])
-        self.assertEquals(self._g("(RX)"), ["Remix"])
-
-    def test_parened_text(self):
-        self.assertEquals(
-            self._g("(00)(02)Real Folk Blues"),
-            ["Blues", "Country", "Real Folk Blues"])
-
-    def test_escape(self):
-        self.assertEquals(self._g("(0)((A genre)"), ["Blues", "(A genre)"])
-        self.assertEquals(self._g("(10)((20)"), ["New Age", "(20)"])
-
-    def test_nullsep(self):
-        self.assertEquals(self._g("0\x00A genre"), ["Blues", "A genre"])
-
-    def test_nullsep_empty(self):
-        self.assertEquals(self._g("\x000\x00A genre"), ["Blues", "A genre"])
-
-    def test_crazy(self):
-        self.assertEquals(
-            self._g("(20)(CR)\x0030\x00\x00Another\x00(51)Hooray"),
-             ['Alternative', 'Cover', 'Fusion', 'Another',
-              'Techno-Industrial', 'Hooray'])
-
-    def test_repeat(self):
-        self.assertEquals(self._g("(20)Alternative"), ["Alternative"])
-        self.assertEquals(
-            self._g("(20)\x00Alternative"), ["Alternative", "Alternative"])
-
-    def test_set_genre(self):
-        gen = self.TCON(encoding=0, text="")
-        self.assertEquals(gen.genres, [])
-        gen.genres = ["a genre", "another"]
-        self.assertEquals(gen.genres, ["a genre", "another"])
-
-    def test_nodoubledecode(self):
-        gen = self.TCON(encoding=1, text=u"(255)genre")
-        gen.genres = gen.genres
-        self.assertEquals(gen.genres, [u"Unknown", u"genre"])
-
 class BrokenDiscarded(TestCase):
-    uses_mmap = False
 
     def test_empty(self):
         from mutagen.id3 import TPE1, ID3JunkFrameError
@@ -1340,7 +992,6 @@ class BrokenDiscarded(TestCase):
         self.assertRaises(ID3JunkFrameError, COMM.fromData, _24, 0x00, data)
 
 class BrokenButParsed(TestCase):
-    uses_mmap = False
 
     def test_missing_encoding(self):
         from mutagen.id3 import TIT2
@@ -1374,7 +1025,7 @@ class BrokenButParsed(TestCase):
                           Frame.FLAG24_COMPRESS, '\x03abcdefg')
 
     def test_zlib_bpi(self):
-        from mutagen.id3 import TPE1, Frame, ID3BadCompressedData
+        from mutagen.id3 import TPE1
         id3 = ID3()
         tpe1 = TPE1(encoding=0, text="a" * (0xFFFF - 2))
         data = id3._ID3__save_frame(tpe1)
@@ -1383,7 +1034,7 @@ class BrokenButParsed(TestCase):
             max(datalen_size) >= '\x80', "data is not syncsafe: %r" % data)
 
     def test_fake_zlib_nopedantic(self):
-        from mutagen.id3 import TPE1, Frame, ID3BadCompressedData
+        from mutagen.id3 import TPE1, Frame
         id3 = ID3()
         id3.PEDANTIC = False
         tpe1 = TPE1.fromData(id3, Frame.FLAG24_COMPRESS, '\x03abcdefg')
@@ -1425,73 +1076,6 @@ class BrokenButParsed(TestCase):
         self.assertEquals('a'*255, tagsbad[0])
 
 
-class TimeStamp(TestCase):
-    uses_mmap = False
-
-    from mutagen.id3 import ID3TimeStamp as Stamp
-
-    def test_Y(self):
-        s = self.Stamp('1234')
-        self.assertEquals(s.year, 1234)
-        self.assertEquals(s.text, '1234')
-
-    def test_yM(self):
-        s = self.Stamp('1234-56')
-        self.assertEquals(s.year, 1234)
-        self.assertEquals(s.month, 56)
-        self.assertEquals(s.text, '1234-56')
-
-    def test_ymD(self):
-        s = self.Stamp('1234-56-78')
-        self.assertEquals(s.year, 1234)
-        self.assertEquals(s.month, 56)
-        self.assertEquals(s.day, 78)
-        self.assertEquals(s.text, '1234-56-78')
-
-    def test_ymdH(self):
-        s = self.Stamp('1234-56-78T12')
-        self.assertEquals(s.year, 1234)
-        self.assertEquals(s.month, 56)
-        self.assertEquals(s.day, 78)
-        self.assertEquals(s.hour, 12)
-        self.assertEquals(s.text, '1234-56-78 12')
-
-    def test_ymdhM(self):
-        s = self.Stamp('1234-56-78T12:34')
-        self.assertEquals(s.year, 1234)
-        self.assertEquals(s.month, 56)
-        self.assertEquals(s.day, 78)
-        self.assertEquals(s.hour, 12)
-        self.assertEquals(s.minute, 34)
-        self.assertEquals(s.text, '1234-56-78 12:34')
-
-    def test_ymdhmS(self):
-        s = self.Stamp('1234-56-78T12:34:56')
-        self.assertEquals(s.year, 1234)
-        self.assertEquals(s.month, 56)
-        self.assertEquals(s.day, 78)
-        self.assertEquals(s.hour, 12)
-        self.assertEquals(s.minute, 34)
-        self.assertEquals(s.second, 56)
-        self.assertEquals(s.text, '1234-56-78 12:34:56')
-
-    def test_Ymdhms(self):
-        s = self.Stamp('1234-56-78T12:34:56')
-        s.month = None
-        self.assertEquals(s.text, '1234')
-
-    def test_alternate_reprs(self):
-        s = self.Stamp('1234-56.78 12:34:56')
-        self.assertEquals(s.text, '1234-56-78 12:34:56')
-
-    def test_order(self):
-        s = self.Stamp('1234')
-        t = self.Stamp('1233-12')
-        u = self.Stamp('1234-01')
-
-        self.assert_(t < s < u)
-        self.assert_(u > s > t)
-
 class OddWrites(TestCase):
     silence = join('tests', 'data', 'silence-44-s.mp3')
     newsilence = join('tests', 'data', 'silence-written.mp3')
@@ -1534,6 +1118,16 @@ class WriteRoundtrip(TestCase):
         self.assertEquals(id3["TIT2"], "Silence")
         self.assertEquals(id3["TPE1"], ["jzig"])
 
+    def test_same_v23(self):
+        id3 = ID3(self.newsilence, v2_version=3)
+        id3.save(v2_version=3)
+        id3 = ID3(self.newsilence)
+        self.assertEqual(id3.version, (2, 3, 0))
+        self.assertEquals(id3["TALB"], "Quod Libet Test Data")
+        self.assertEquals(id3["TCON"], "Silence")
+        self.assertEquals(id3["TIT2"], "Silence")
+        self.assertEquals(id3["TPE1"], "jzig")
+
     def test_addframe(self):
         from mutagen.id3 import TIT3
         f = ID3(self.newsilence)
@@ -1544,7 +1138,6 @@ class WriteRoundtrip(TestCase):
         self.assertEquals(id3["TIT3"], "A subtitle!")
 
     def test_changeframe(self):
-        from mutagen.id3 import TIT2
         f = ID3(self.newsilence)
         self.assertEquals(f["TIT2"], "Silence")
         f["TIT2"].text = [u"The sound of silence."]
@@ -1665,7 +1258,6 @@ class WriteForEyeD3(TestCase):
         self.assertEquals(id3.frames["TIT3"][0].text, "A subtitle!")
 
     def test_changeframe(self):
-        from mutagen.id3 import TIT2
         f = ID3(self.newsilence)
         self.assertEquals(f["TIT2"], "Silence")
         f["TIT2"].text = [u"The sound of silence."]
@@ -1677,34 +1269,11 @@ class WriteForEyeD3(TestCase):
     def tearDown(self):
         os.unlink(self.newsilence)
 
-class NoHash(TestCase):
-    uses_mmap = False
-
-    def test_spec(self):
-        from mutagen.id3 import Spec
-        self.failUnlessRaises(TypeError, {}.__setitem__, Spec("foo"), None)
-
-    def test_frame(self):
-        from mutagen.id3 import TIT1
-        self.failUnlessRaises(
-            TypeError, {}.__setitem__, TIT1(encoding=0, text="foo"), None)
-
-class FrameIDValidate(TestCase):
-    uses_mmap = False
-
-    def test_valid(self):
-        from mutagen.id3 import is_valid_frame_id
-        self.failUnless(is_valid_frame_id("APIC"))
-        self.failUnless(is_valid_frame_id("TPE2"))
-
-    def test_invalid(self):
-        from mutagen.id3 import is_valid_frame_id
-        self.failIf(is_valid_frame_id("MP3e"))
-        self.failIf(is_valid_frame_id("+ABC"))
 
 class BadTYER(TestCase):
-    uses_mmap = False
+
     filename = join('tests', 'data', 'bad-TYER-frame.mp3')
+
     def setUp(self):
         self.audio = ID3(self.filename)
 
@@ -1718,7 +1287,7 @@ class BadTYER(TestCase):
         del(self.audio)
 
 class BadPOPM(TestCase):
-    uses_mmap = False
+
     filename = join('tests', 'data', 'bad-POPM-frame.mp3')
     newfilename = join('tests', 'data', 'bad-POPM-frame-written.mp3')
 
@@ -1748,17 +1317,8 @@ class BadPOPM(TestCase):
         self.assertEquals(popm.rating, 125)
         self.assertEquals(popm.count, 2**32+1)
 
-class TimeStampTextFrame(TestCase):
-    uses_mmap = False
-
-    from mutagen.id3 import TimeStampTextFrame as Frame
-
-    def test_compare_to_unicode(self):
-        frame = self.Frame(encoding=0, text=[u'1987', u'1988'])
-        self.failUnlessEqual(frame, unicode(frame))
 
 class Issue69_BadV1Year(TestCase):
-    uses_mmap = False
 
     def test_missing_year(self):
         from mutagen.id3 import ParseID3v1
@@ -1772,52 +1332,175 @@ class Issue69_BadV1Year(TestCase):
         self.failUnlessEqual(tag["TDRC"], "0001")
 
     def test_none(self):
-        from mutagen.id3 import ParseID3v1, MakeID3v1, TDRC
+        from mutagen.id3 import ParseID3v1, MakeID3v1
         s = MakeID3v1(dict())
         self.failUnlessEqual(len(s), 128)
         tag = ParseID3v1(s)
         self.failIf("TDRC" in tag)
 
     def test_empty(self):
-        from mutagen.id3 import ParseID3v1, MakeID3v1, TDRC
+        from mutagen.id3 import ParseID3v1, MakeID3v1
         s = MakeID3v1(dict(TDRC=""))
         self.failUnlessEqual(len(s), 128)
         tag = ParseID3v1(s)
         self.failIf("TDRC" in tag)
 
     def test_short(self):
-        from mutagen.id3 import ParseID3v1, MakeID3v1, TDRC
+        from mutagen.id3 import ParseID3v1, MakeID3v1
         s = MakeID3v1(dict(TDRC="1"))
         self.failUnlessEqual(len(s), 128)
         tag = ParseID3v1(s)
         self.failUnlessEqual(tag["TDRC"], "0001")
 
     def test_long(self):
-        from mutagen.id3 import ParseID3v1, MakeID3v1, TDRC
+        from mutagen.id3 import ParseID3v1, MakeID3v1
         s = MakeID3v1(dict(TDRC="123456789"))
         self.failUnlessEqual(len(s), 128)
         tag = ParseID3v1(s)
         self.failUnlessEqual(tag["TDRC"], "1234")
 
+
+class UpdateTo23(TestCase):
+
+    def test_tdrc(self):
+        tags = ID3()
+        tags.add(id3.TDRC(encoding=1, text="2003-04-05 12:03"))
+        tags.update_to_v23()
+        self.failUnlessEqual(tags["TYER"].text, ["2003"])
+        self.failUnlessEqual(tags["TDAT"].text, ["0504"])
+        self.failUnlessEqual(tags["TIME"].text, ["1203"])
+
+    def test_tdor(self):
+        tags = ID3()
+        tags.add(id3.TDOR(encoding=1, text="2003-04-05 12:03"))
+        tags.update_to_v23()
+        self.failUnlessEqual(tags["TORY"].text, ["2003"])
+
+    def test_genre_from_v24_1(self):
+        tags = ID3()
+        tags.add(id3.TCON(encoding=1, text=["4","Rock"]))
+        tags.update_to_v23()
+        self.failUnlessEqual(tags["TCON"].text, ["Disco", "Rock"])
+
+    def test_genre_from_v24_2(self):
+        tags = ID3()
+        tags.add(id3.TCON(encoding=1, text=["RX", "3", "CR"]))
+        tags.update_to_v23()
+        self.failUnlessEqual(tags["TCON"].text, ["Remix", "Dance", "Cover"])
+
+    def test_genre_from_v23_1(self):
+        tags = ID3()
+        tags.add(id3.TCON(encoding=1, text=["(4)Rock"]))
+        tags.update_to_v23()
+        self.failUnlessEqual(tags["TCON"].text, ["Disco", "Rock"])
+
+    def test_genre_from_v23_2(self):
+        tags = ID3()
+        tags.add(id3.TCON(encoding=1, text=["(RX)(3)(CR)"]))
+        tags.update_to_v23()
+        self.failUnlessEqual(tags["TCON"].text, ["Remix", "Dance", "Cover"])
+
+    def test_ipls(self):
+        tags = ID3()
+        tags.version = (2, 3)
+        tags.add(id3.TIPL(encoding=0, people=[["a", "b"], ["c", "d"]]))
+        tags.add(id3.TMCL(encoding=0, people=[["e", "f"], ["g", "h"]]))
+        tags.update_to_v23()
+        self.failUnlessEqual(tags["IPLS"], [["a", "b"], ["c", "d"],
+                                            ["e", "f"], ["g", "h"]])
+
+class WriteTo23(TestCase):
+
+    SILENCE = os.path.join("tests", "data", "silence-44-s.mp3")
+
+    def setUp(self):
+        from tempfile import mkstemp
+        fd, self.filename = mkstemp(suffix='.mp3')
+        os.close(fd)
+        shutil.copy(self.SILENCE, self.filename)
+        self.audio = ID3(self.filename)
+
+    def tearDown(self):
+        os.unlink(self.filename)
+
+    def test_update_to_v23_on_load(self):
+        from mutagen.id3 import TSOT
+        self.audio.add(TSOT(text=["Ha"], encoding=3))
+        self.audio.save()
+
+        # update_to_v23 called
+        id3 = ID3(self.filename, v2_version=3)
+        self.assertFalse(id3.getall("TSOT"))
+
+        # update_to_v23 not called
+        id3 = ID3(self.filename, v2_version=3, translate=False)
+        self.assertTrue(id3.getall("TSOT"))
+
+    def test_load_save_inval_version(self):
+        self.assertRaises(ValueError, self.audio.save, v2_version=5)
+        self.assertRaises(ValueError, ID3, self.filename, v2_version=5)
+
+    def test_save(self):
+        strings = ["one", "two", "three"]
+        from mutagen.id3 import TPE1
+        self.audio.add(TPE1(text=strings, encoding=3))
+        self.audio.save(v2_version=3)
+
+        frame = self.audio["TPE1"]
+        self.assertEqual(frame.encoding, 3)
+        self.assertEqual(frame.text, strings)
+
+        id3 = ID3(self.filename, translate=False)
+        self.assertEqual(id3.version, (2, 3, 0))
+        frame = id3["TPE1"]
+        self.assertEqual(frame.encoding, 1)
+        self.assertEqual(frame.text, ["/".join(strings)])
+
+        # null separator, mutagen can still read it
+        self.audio.save(v2_version=3, v23_sep=None)
+
+        id3 = ID3(self.filename, translate=False)
+        self.assertEqual(id3.version, (2, 3, 0))
+        frame = id3["TPE1"]
+        self.assertEqual(frame.encoding, 1)
+        self.assertEqual(frame.text, strings)
+
+    def test_save_off_spec_frames(self):
+        # These are not defined in v2.3 and shouldn't be written.
+        # Still make sure reading them again works and the encoding
+        # is at least changed
+
+        from mutagen.id3 import TDEN, TIPL
+        dates = ["2013", "2014"]
+        frame = TDEN(text=dates, encoding=3)
+        self.audio.add(frame)
+        tipl_frame = TIPL(people=[("a", "b"), ("c", "d")], encoding=2)
+        self.audio.add(tipl_frame)
+        self.audio.save(v2_version=3)
+
+        id3 = ID3(self.filename, translate=False)
+        self.assertEqual(id3.version, (2, 3, 0))
+
+        self.assertEqual([stamp.text for stamp in id3["TDEN"].text], dates)
+        self.assertEqual(id3["TDEN"].encoding, 1)
+
+        self.assertEqual(id3["TIPL"].people, tipl_frame.people)
+        self.assertEqual(id3["TIPL"].encoding, 1)
+
+
 add(ID3Loading)
 add(ID3GetSetDel)
-add(BitPaddedIntTest)
 add(ID3Tags)
 add(ID3v1Tags)
 add(BrokenDiscarded)
 add(BrokenButParsed)
-add(FrameSanityChecks)
-add(SpecSanityChecks)
-add(Genres)
-add(TimeStamp)
 add(WriteRoundtrip)
 add(OddWrites)
-add(NoHash)
-add(FrameIDValidate)
 add(BadTYER)
 add(BadPOPM)
-add(TimeStampTextFrame)
 add(Issue69_BadV1Year)
+add(UpdateTo23)
+add(WriteTo23)
 
 try: import eyeD3
 except ImportError: pass
